<?php


namespace ExtendThemes\MagnusWP;


use ColibriWP\Theme\Components\CSSOutput;
use ColibriWP\Theme\Components\FrontHeader\Hero;
use ColibriWP\Theme\Defaults;
use ColibriWP\Theme\Translations;

class FrontPageHero extends Hero {

    protected static function getOptions( $include_content_settings = true ) {
        $options = Hero::getOptions( $include_content_settings );

        $texts_selectors = array(
            Hero::selectiveRefreshSelector() . " h1",
            Hero::selectiveRefreshSelector() . " .h-text p"
        );

		$selector = Hero::selectiveRefreshSelector();

        $options['settings'] = array_merge( (array) $options['settings'],
            array(
                "header_front_page.hero.separator-before-white-texts" => array(
                    'default' => '',
                    'control' => array(
                        'label'       => '',
                        'type'        => 'separator',
                        'section'     => 'hero',
                        'colibri_tab' => 'style',
                    ),
                ),

                'header_front_page.hero.style.white-texts' => array(
                    'default'    => false,
                    'control'    => array(
                        'label'       => __( 'Make texts white', 'magnus-wp' ),
                        'type'        => 'switch',
                        'section'     => 'hero',
                        'colibri_tab' => 'style',
                    ),
                    'css_output' => array(
                        array(
                            'selector'    => implode( ",", $texts_selectors ),
                            'media'       => CSSOutput::NO_MEDIA,
                            'property'    => 'color',
                            'true_value'  => '#ffffff !important',
                            'false_value' => 'inherit',
                        ),
                    ),
                ),
                
			"header_front_page.hero.props.heroSection.layout" => array(
                'default'    => '',
                 'control'    => array(
                    'label'       => Translations::get( 'hero_layout' ),
                    'focus_alias' => "hero_layout",
                    'type'        => 'select-icon',
                    'section'     => 'hero',
                    'colibri_tab' => 'content',
                    'choices'     => array(
                        'textOnly' =>
                            array(
                                'tooltip' => Translations::get( 'text_only' ),
                                'label'   => Translations::get( 'text_only' ),
                                'value'   => 'textOnly',
                                'icon'    => Defaults::get( 'icons.textOnly.content' ),
                            ),

                        'textWithMediaOnRight' =>
                            array(
                                'tooltip' => Translations::get( 'text_with_media_on_right' ),
                                'label'   => Translations::get( 'text_with_media_on_right' ),
                                'value'   => 'textWithMediaOnRight',
                                'icon'    => Defaults::get( 'icons.textWithMediaOnRight.content' ),
                            ),

                        'textWithMediaOnLeft' =>
                            array(
                                'tooltip' => Translations::get( 'text_with_media_on_left' ),
                                'label'   => Translations::get( 'text_with_media_on_left' ),
                                'value'   => 'textWithMediaOnLeft',
                                'icon'    => Defaults::get( 'icons.textWithMediaOnLeft.content' ),
                            ),
                    ),
                ),
                'css_output' => array(
                    array(
                        'selector' => "{$selector} .h-column-container",
                        'media'    => CSSOutput::desktopMedia(),
                        'property' => 'width',
                        'value'    => array(
                            'textOnly'             => '100%',
                            'textWithMediaOnRight' => '50%',
                            'textWithMediaOnLeft'  => '50%',
                        ),
                    ),
                    array(
                        'selector' => "{$selector} .h-column-container:nth-child(1)",
                        'media'    => CSSOutput::desktopMedia(),
                        'property' => 'order',
                        'value'    => array(
                            'textOnly'             => '0',
                            'textWithMediaOnRight' => '0',
                            'textWithMediaOnLeft'  => '1',
                        ),
                    ),
                    array(
                        'selector' => "{$selector} .h-column-container:nth-child(2)",
                        'media'    => CSSOutput::desktopMedia(),
                        'property' => 'display',
                        'value'    => array(
                            'textOnly'             => 'none',
                            'textWithMediaOnRight' => 'block',
                            'textWithMediaOnLeft'  => 'block',
                        ),
                    ),
                    array(
                        'selector' => "{$selector} .h-column-container:nth-child(1) > div",
                        'media'    => CSSOutput::desktopMedia(),
                        'property' => 'transform',
                        'value'    => array(
                            'textOnly'             => 'none',
                            'textWithMediaOnRight' => 'translateX(10%) translateY(0%)',
                            'textWithMediaOnLeft'  => 'translateX(-10%) translateY(0%)',
                        ),
                    ),
                    array(
                        'selector' => "{$selector} .h-column-container:nth-child(2) > div",
                        'media'    => CSSOutput::desktopMedia(),
                        'property' => 'transform',
                        'value'    => array(
                            'textOnly'             => 'none',
                            'textWithMediaOnRight' => 'translateX(-10%) translateY(0%)',
                            'textWithMediaOnLeft'  => 'translateX(10%) translateY(0%)',
                        ),
                    )
                ),
            ), 
        ) );

        return $options;
    }
}
